@@ -6,7 +6,7 @@ import json
 from amaascore.config import ENVIRONMENT
 from amaascore.core.amaas_model import json_handler
 from amaascore.core.interface import Interface
-from amaascore.transactions.utils import json_to_transaction, json_to_position, json_to_mtm_result
+from amaascore.transactions.utils import json_to_transaction, json_to_position, json_to_mtm_result, json_to_pnl_result
 
 
 class TransactionsInterface(Interface):
@@ -165,7 +165,7 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def new_mtm_result(self, asset_manager_id, mtm_results):
+    def new_mtm_results(self, asset_manager_id, mtm_results):
         self.logger.info('Marking to market Positions - Asset Manager: %s', asset_manager_id)
         if not isinstance(mtm_results, list):
             mtm_results = [mtm_results]
@@ -183,7 +183,7 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def amend_mtm_result(self, asset_manager_id, mtm_results):
+    def amend_mtm_results(self, asset_manager_id, mtm_results):
         self.logger.info('Amending mtm Positions - Asset Manager: %s', asset_manager_id)
         if not isinstance(mtm_results, list):
             mtm_results = [mtm_results]
@@ -201,7 +201,7 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def retrieve_mtm_result(self, book_id, asset_manager_id, paramaters):
+    def retrieve_mtm_results(self, book_id, asset_manager_id, paramaters):
         """
         parameters is a dictionary of all the mtm result filter parameters
         """
@@ -217,8 +217,78 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
+    def new_pnl_results(self, asset_manager_id, pnl_results):
+        self.logger.info('Insert PnL results for - Asset Manager: %s', asset_manager_id)
+        if not isinstance(pnl_results, list):
+            pnl_results = [pnl_results]
+        pnl_result_json = []
+        for pnl_result in pnl_results:
+            pnl_result_json.append(pnl_result.to_interface())
+        url = '%s/pnl/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.post(url, json=pnl_result_json)
+        if response.ok:
+            pnl_results = []
+            for pnl_result_json in response.json():
+                pnl_results.append(json_to_pnl_result(pnl_result_json))
+            return pnl_results
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+    def amend_pnl_results(self, asset_manager_id, pnl_results):
+        self.logger.info('Amend PnL results for - Asset Manager: %s', asset_manager_id)
+        if not isinstance(pnl_results, list):
+            pnl_results = [pnl_results]
+        pnl_result_json = []
+        for pnl_result in pnl_results:
+            pnl_result_json.append(pnl_result.to_interface())
+        url = '%s/pnl/%s' % (self.endpoint, asset_manager_id)
+        response = self.session.put(url, json=pnl_result_json)
+        if response.ok:
+            pnl_results = []
+            for pnl_result_json in response.json():
+                pnl_results.append(json_to_pnl_result(pnl_result_json))
+            return pnl_results
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+    def retrieve_pnl_results(self, book_ids, asset_manager_id, business_date, periods=None):
+        self.logger.info('Retrieving PnL result - Asset Manager: %s - Book IDs: (%s) - Business Date: %s' % \
+                        (asset_manager_id, ', '.join(book_ids), business_date))
+        url = '%s/pnl/%s' % (self.endpoint, asset_manager_id)
+        search_params = {'business_date': business_date,
+                         'book_ids': book_ids}
+        if periods:
+            search_params['periods'] = periods
+        response = self.session.get(url, params=search_params)
+        if response.ok:
+            pnl_results = [json_to_pnl_result(json_pnl_result) for json_pnl_result in response.json()]
+            self.logger.info('Returned %s PnL results.', len(pnl_results))
+            return pnl_results
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()
+
+    def get_pnl_transactions(self, book_id, asset_manager_id, start_date, end_date):
+        self.logger.info('Retrieving transactions for PnL - Asset Manager: %s - Book ID: %s'%(asset_manager_id, book_id))
+        url = '%s/pnl_transactions/%s' % (self.endpoint, asset_manager_id)
+        search_params = {'asset_manager_id': asset_manager_id,
+                         'start_date': start_date,
+                         'book_id': book_id,
+                         'end_date': end_date}
+        response = self.session.get(url, params=search_params)
+        if response.ok:
+            transactions = [json_to_transaction(json_transaction) for json_transaction in response.json()]
+            self.logger.info('Returned %s Transactions.', len(transactions))
+            return transactions
+        else:
+            self.logger.error(response.text)
+            response.raise_for_status()        
+
     def position_search(self, asset_manager_id, book_ids=None, account_ids=None,
-                        accounting_types=['Transaction Date'], asset_ids=None, position_date=None):
+                        accounting_types=['Transaction Date'], asset_ids=None,
+                        position_date=None, include_cash=False):
         self.logger.info('Search Positions - Asset Manager: %s', asset_manager_id)
         search_params = {}
         # Potentially roll into a loop
@@ -232,6 +302,8 @@ class TransactionsInterface(Interface):
             search_params['asset_ids'] = ','.join(asset_ids)
         if position_date:
             search_params['position_date'] = position_date
+        if include_cash:
+            search_params['include_cash'] = include_cash
         url = '%s/positions/%s' % (self.endpoint, asset_manager_id)
         response = self.session.get(url, params=search_params)
         if response.ok:
@@ -353,36 +425,6 @@ class TransactionsInterface(Interface):
             self.logger.error(response.text)
             response.raise_for_status()
 
-    def upsert_transaction_asset(self, transaction_asset_json):
-        """
-        This API should not be called in normal circumstances as the asset cache will populate itself from the assets
-        which are created via the Assets API.  However, it can be useful for certain testing scenarios.
-        :param transaction_asset_json:
-        :return:
-        """
-        url = self.endpoint + '/assets'
-        response = self.session.post(url, json=transaction_asset_json)
-        if response.ok:
-            return response.json()
-        else:
-            self.logger.error(response.text)
-            response.raise_for_status()
-
-    def upsert_transaction_book(self, transaction_book_json):
-        """
-        This API should not be called in normal circumstances as the book cache will populate itself from the book
-        which are created via the Books API.  However, it can be useful for certain testing scenarios.
-        :param transaction_book_json:
-        :return:
-        """
-        url = self.endpoint + '/books'
-        response = self.session.post(url, json=transaction_book_json)
-        if response.ok:
-            return response.json()
-        else:
-            self.logger.error(response.text)
-            response.raise_for_status()
-
     def book_transfer(self, asset_manager_id, asset_id, source_book_id, target_book_id, wash_book_id, quantity, price,
                       currency):
         """
